# Changelog


## [1.1.3] - 2026-03-25

### Fixed

- Import error for types in `legacy` module.


## [1.1.2] - 2026-03-17

### Fixed

- Reduce repepeated text in documentation.


## [1.1.1] - 2026-03-16

### Fixed

- Restructure documentation.


## [1.1.0] - 2026-03-15

### Added

- Screenshot for `RichHandler` output.

### Fixed

- Padding of log level for `RichHandler`, matching `rich.logging.RichHandler` behavior.
- Use new URL for screenshot.


## [1.0.0] - 2026-03-15

### Added

- `RichHandler` for colorful console output with syntax highlighting.
- `JournaldHandler` for structured logging to systemd journal (Linux only).
- `logbook-stubs` package.
- Test cases.

### Changed

- Major rewrite from legacy codebase.


## [0.2.0] - 2020-10-16

- Legacy release (project was rewritten for v1.0.0)


[1.1.3]: https://github.com/hongquan/chameleon-log/releases/tag/v1.1.3
[1.1.2]: https://github.com/hongquan/chameleon-log/releases/tag/v1.1.2
[1.1.1]: https://github.com/hongquan/chameleon-log/releases/tag/v1.1.1
[1.1.0]: https://github.com/hongquan/chameleon-log/releases/tag/v1.1.0
[1.0.0]: https://github.com/hongquan/chameleon-log/releases/tag/v1.0.0
[0.2.0]: https://github.com/hongquan/chameleon-log/releases/tag/v0.2.0
